@@ -1,6 +1,5 @@
 package Path::Resolver::Resolver::DataSection;
-our $VERSION = '3.092200';
-
+our $VERSION = '3.100450';
 # ABSTRACT: find content in a package's Data::Section content
 use Moose;
 with 'Path::Resolver::Role::Resolver';
@@ -48,7 +47,6 @@ sub entity_at {
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -57,7 +55,7 @@ Path::Resolver::Resolver::DataSection - find content in a package's Data::Sectio
 
 =head1 VERSION
 
-version 3.092200
+version 3.100450
 
 =head1 SYNOPSIS
 
@@ -65,7 +63,7 @@ version 3.092200
     module => 'YourApp::Config::InData',
   });
 
-  my $simple_entity = $resolver->entity_for('foo/bar.txt');
+  my $simple_entity = $resolver->entity_at('foo/bar.txt');
 
 This class assumes that you will give it the name of another package and that
 that package uses L<Data::Section|Data::Section> to retrieve named content from
@@ -93,11 +91,10 @@ a package.  The default is Data::Section's default: C<section_data>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo Signes.
+This software is copyright (c) 2010 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
